@@ -1,17 +1,19 @@
 use fixed_queue::Spsc;
-static mut SPSC: Spsc<u8, 4> = Spsc::new();
+static SPSC: Spsc<u8, 3> = Spsc::new();
 
 fn main() {
-    let (sender, recver) = unsafe { SPSC.channel() };
-    //panic: unsafe { SPSC.channel() };
+    let sender = SPSC.take_sender().unwrap();
+    let recver = SPSC.take_recver().unwrap();
+    let tmp_sender = SPSC.take_sender();
+    let tmp_recver = SPSC.take_recver();
+    assert!(tmp_sender.is_none());
+    assert!(tmp_recver.is_none());
 
-    assert_eq!(unsafe { SPSC.capacity() }, 4);
+    assert_eq!(SPSC.capacity(), 3);
     assert!(sender.send(1).is_ok());
     assert!(sender.send(2).is_ok());
     assert!(sender.send(3).is_ok());
-    assert!(sender.send(4).is_ok());
-    assert!(sender.send(5).is_err());
-    println!("{:?}", recver.try_recv());
+    assert!(sender.send(4).is_err());
     println!("{:?}", recver.try_recv());
     println!("{:?}", recver.try_recv());
     println!("{:?}", recver.try_recv());
