@@ -1,8 +1,8 @@
 use fixed_queue::VecDeque;
 
 fn main() {
-    let mut vec: VecDeque<u8, 4> = VecDeque::new();
-    assert_eq!(vec.capacity(), 4-1);
+    let mut vec: VecDeque<u8, 3> = VecDeque::new();
+    assert_eq!(vec.capacity(), 3);
     assert!(vec.is_empty());
     vec.push_back(1);
     println!("{}", vec[0]);
@@ -13,7 +13,6 @@ fn main() {
     println!("{:?}", vec.pop_back());
     println!("{:?}", vec.pop_back());
     println!("{:?}", vec.pop_back());
-    println!("{:?}", vec.pop_back());
-    println!("{:?}", vec.pop_back());
+    println!("{:?}", vec.pop_front());
     println!("{:?}", vec.pop_back());
 }
