@@ -1,7 +1,5 @@
 #![no_std]
 #![feature(const_fn)]
-#![feature(const_mut_refs)]
-#![feature(const_panic)]
 #![feature(const_generics)]
 #![feature(const_evaluatable_checked)]
 
